@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
-package fio;
-our $VERSION = 0.0.1;
+package cfwp::fio;
+our $VERSION = 0.0.3;
 
 use Modern::Perl;
 
